import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { render, screen } from '@testing-library/react';
import { DrawerHeadingBackwardButton } from './DrawerHeadingBackwardButton.component';

const backwardFunction = jest.fn();

const renderComponent = (
  title: string,
  value: string,
  initialStoreState: InitialStoreState = {},
): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <DrawerHeadingBackwardButton
          title={title}
          value={value}
          backwardFunction={backwardFunction}
        />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('DrawerHeadingBackwardButton - component', () => {
  beforeEach(() => {
    backwardFunction.mockReset();
  });

  it('should render passed values', () => {
    renderComponent('Title', 'value');

    expect(screen.getByRole('back-button')).toBeInTheDocument();
    expect(screen.getByText('Title:')).toBeInTheDocument();
    expect(screen.getByText('value')).toBeInTheDocument();
    expect(screen.getByRole('close-drawer-button')).toBeInTheDocument();
  });

  it('should call backward function on back button click', () => {
    renderComponent('Title', 'value');

    const backButton = screen.getByRole('back-button');
    backButton.click();

    expect(backwardFunction).toBeCalled();
  });

  it('should call class drawer on close button click', () => {
    const { store } = renderComponent('Title', 'value', {
      drawer: { isOpen: true, drawerName: 'search' },
    });
    expect(store.getState().drawer.isOpen).toBe(true);

    const closeButton = screen.getByRole('close-drawer-button');
    closeButton.click();

    expect(store.getState().drawer.isOpen).toBe(false);
  });
});
